@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     LiuMingHang <liuminghang@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020-2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifdef CMAKE_BUILD
 #include "config.h"
@@ -43,6 +26,7 @@
 
 #include "mainwindow/mainwindow.h"
 #include "application.h"
+#include "eventlogutils.h"
 
 //using namespace Dtk::Core;
 
@@ -52,7 +36,15 @@
 
 DWIDGET_USE_NAMESPACE
 DCORE_USE_NAMESPACE
-
+//解析
+static QString getImagenameFromPath(const QString &path_name)
+{
+    QStringList list = path_name.split(".");
+    if (list.isEmpty())
+        return " ";
+    else
+        return list.last();
+}
 bool checkOnly()
 {
     //single
@@ -189,16 +181,28 @@ int main(int argc, char *argv[])
         mainwindow->setMinimumSize(MAINWIDGET_MINIMUN_WIDTH, MAINWIDGET_MINIMUN_HEIGHT);
     }
     QString filepath = "";
+    QString imageformat = "";
+    bool bRet = false;
     QStringList arguments = QCoreApplication::arguments();
     for (QString path : arguments) {
         path = UrlInfo(path).toLocalFile();
         if (QFileInfo(path).isFile()) {
-            bool bRet = w->slotDrogImg(QStringList(path));
+            bRet = w->slotDrogImg(QStringList(path));
             if (bRet) {
+                imageformat = getImagenameFromPath(path);
                 break;
             }
         }
     }
+    //埋点记录启动数据
+    QJsonObject objStartEvent{
+        {"tid", Eventlogutils::StartUp},
+        {"vsersion", VERSION},
+        {"imageformat", imageformat},
+        {"opensuccess", bRet},
+        {"mode", 1},
+    };
+    Eventlogutils::GetInstance()->writeLogs(objStartEvent);
 
     mainwindow->show();
 
