@@ -3,9 +3,9 @@ rm -r build-ut
 rm -r ../build-ut
 mkdir ../build-ut
 cd ../build-ut
-cmake -DCMAKE_BUILD_TYPE=Debug ..
+cmake -DCMAKE_BUILD_TYPE=Debug .. -D DOTEST=ON
 make -j16
-export QTEST_FUNCTION_TIMEOUT='700000'
+export QTEST_FUNCTION_TIMEOUT='1000000'
 workdir=$(cd ../$(dirname $0)/build-ut; pwd)
 PROJECT_NAME=deepin-image-viewer-test #可执行程序的文件名
 PROJECT_REALNAME=deepin-image-viewer  #项目名称
